@@ -22,7 +22,8 @@ if sys.argv[1] == 'config':
             f.write('''from pytsharp_utils.compiler import cmp
 
 cmp('app.tsh')
-''')        os.system('echo !Run __main__.py to compile > app.tsh')
+''')
+            os.system('echo !Run __main__.py to compile > app.tsh')
             os.system('code app.tsh')
             os.system('code __main__.py')
 
